#ifndef SRC_MULTI_BODY_PROBLEM_DATA_WEAKPATCH_HH
#define SRC_MULTI_BODY_PROBLEM_DATA_WEAKPATCH_HH

#include "cuboidgeometry.hh"

template <class LocalVector>
ConvexPolyhedron<LocalVector> getWeakPatch(Dune::ParameterTree const &parset, CuboidGeometry const &cuboidGeometry) {
  ConvexPolyhedron<LocalVector> weakPatch;
#if MY_DIM == 3
  weakPatch.vertices.resize(4);
  weakPatch.vertices[0] = weakPatch.vertices[2] = cuboidGeometry.X;
  weakPatch.vertices[1] = weakPatch.vertices[3] = cuboidGeometry.Y;
  for (size_t k = 0; k < 2; ++k) {
    weakPatch.vertices[k][2] = -cuboidGeometry.depth / 2.0;
    weakPatch.vertices[k + 2][2] = cuboidGeometry.depth / 2.0;
  }
  switch (parset.get<Config::PatchType>("patchType")) {
    case Config::Rectangular:
      break;
    case Config::Trapezoidal:
      weakPatch.vertices[1][0] += 0.05 * cuboidGeometry.lengthScale;
      weakPatch.vertices[3][0] -= 0.05 * cuboidGeometry.lengthScale;
      break;
    default:
      assert(false);
  }
#else
  weakPatch.vertices.resize(2);
  weakPatch.vertices[0] = cuboidGeometry.X;
  weakPatch.vertices[1] = cuboidGeometry.Y;
#endif
  return weakPatch;
};
#endif
